@@ -1,9 +1,17 @@
 
 import cv2
 import math
+import pkg_resources
+
+#ageProto = "kraken_image_processing/models/age_deploy.prototxt"
+#ageModel = "kraken_image_processing/models/age_net.caffemodel"
+
+
+ageProto = pkg_resources.resource_stream(__name__, 'models/age_deploy.prototxt')
+
+ageModel = pkg_resources.resource_stream(__name__, 'models/age_net.caffemodel')
+
 
-ageProto = "kraken_image_processing/models/age_deploy.prototxt"
-ageModel = "kraken_image_processing/models/age_net.caffemodel"
 
 MODEL_MEAN_VALUES = (78.4263377603, 87.7689143744, 114.895847746)
 ageList = ['(0-2)', '(4-6)', '(8-12)', '(15-20)', '(25-32)', '(38-43)', '(48-53)', '(60-100)']
