@@ -1,10 +1,11 @@
 import cv2
 import uuid
 from fer import FER
+import pkg_resources
 
 
-
-embedder = cv2.dnn.readNetFromTorch('kraken_image_processing/models/nn4.small2.v1.t7')
+model = pkg_resources.resource_stream(__name__, 'models/nn4.small2.v1.t7')
+embedder = cv2.dnn.readNetFromTorch(model)
 
 
 def get(image):
