@@ -1,11 +1,19 @@
 
 import cv2
 import math
+import pkg_resources
 
 
 
-genderProto = "kraken_image_processing/models/gender_deploy.prototxt"
-genderModel = "kraken_image_processing/models/gender_net.caffemodel"
+#genderProto = "kraken_image_processing/models/gender_deploy.prototxt"
+#genderModel = "kraken_image_processing/models/gender_net.caffemodel"
+
+
+genderProto = pkg_resources.resource_stream(__name__, 'models/gender_deploy.prototxt')
+
+genderModel = pkg_resources.resource_stream(__name__, 'models/gender_net.caffemodel')
+
+
 
 MODEL_MEAN_VALUES = (78.4263377603, 87.7689143744, 114.895847746)
 
